from django.db import migrations
from arkindex_common.enums import MetaType
from django.db.models import Q


def update_balsac_pages(apps, schema_editor):
    MetaData = apps.get_model('documents', 'MetaData')
    balsac_pages_ref_md = MetaData.objects \
        .filter(
            element__corpus__name__in=('Balsac | S3', 'Balsac | From S3'),
            element__type__slug='page'
        ).filter(
            Q(name="name") | Q(name="filename")
        )
    renamed_pages_count = balsac_pages_ref_md.update(name='balsac_id')
    print('Renamed {} reference metadata from BALSAC pages'.format(renamed_pages_count))
    balsac_ref_metadata = MetaData.objects \
        .filter(element__corpus__name__in=('Balsac | S3', 'Balsac | From S3'), name='Reference')
    renamed_other_count = balsac_ref_metadata.update(name='balsac_id')
    print('Renamed {} reference metadata from all BALSAC elements'.format(renamed_other_count))


def reference_metadata(apps, schema_editor):
    """
    Update reference
    """
    MetaData = apps.get_model('documents', 'MetaData')
    references = MetaData.objects.filter(name='balsac_id', type=MetaType.Text)
    moved_count = references.update(type=MetaType.Reference)
    print('Moved {} reference metadata to Reference type'.format(moved_count))


def reverse_migration(apps, schema_editor):
    MetaData = apps.get_model('documents', 'MetaData')
    MetaData.objects.filter(type=MetaType.Reference).update(type=MetaType.Text)


class Migration(migrations.Migration):

    dependencies = [
        ('documents', '0031_remove_entity_metatype'),
    ]

    operations = [
        migrations.RunPython(update_balsac_pages, migrations.RunPython.noop),
        migrations.RunPython(reference_metadata, reverse_migration)
    ]
